.. Flight Arbitrage documentation master file, created by
   sphinx-quickstart on Mon Aug 16 22:27:28 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Flight Arbitrage's documentation!
============================================

.. toctree::
   :maxdepth: 2
   :caption: Quickstart

   quickstart

.. toctree::
   :maxdepth: 2
   :caption: Cookbook

   modules


